@@ -677,10 +677,36 @@ public class Imager {
 	}
     }
     
+// Catch OutOfMemoryError in case user requests too many pixels
+//    protected Image loadImage() throws Exception {
+//	try {
+//            double[] data   = new double[nx*ny*this.nz];
+//            return new Image(data, wcs, nx, ny, nz);
+//        } catch (OutOfMemoryError e) {
+//          System.err.println("Too big");
+//          throw new Exception("Requested image size is too large, please try again using fewer pixels: " +e);
+//        }
+//    }
+    
+//    public class ImageSizeException extends Exception {
+//        public ImageSizeException(String errorMessage) {
+//            super(errorMessage);
+//        }
+//    }
+    
     protected Image loadImage() throws Exception {
-	double[] data   = new double[nx*ny*this.nz];
-	return new Image(data, wcs, nx, ny, nz);
+	try {
+            double[] data   = new double[nx*ny*this.nz];
+            return new Image(data, wcs, nx, ny, nz);
+        } catch (NegativeArraySizeException e) {
+          System.err.println("Requested pixel input too large");
+          throw new Error("Requested image size is too large, please try again using fewer pixels (" +e +")");
+        } catch (OutOfMemoryError e) {
+          System.err.println("Requested pixel input too large");
+          throw new Error("Requested image size is too large, please try again using fewer pixels (" +e +")");
+        }
     }
+   
     
     protected Image[] loadCandidates(Position pos, Survey surv) throws Exception {
         // Get max scale using scale and image size
